@@ -1,5 +1,7 @@
 
 findCorrelation_fast <- function(x, cutoff = .90, verbose = FALSE){
+  if(any(!complete.cases(x)))
+    stop("The correlation matrix has some missing values.")
   averageCorr <- colMeans(abs(x))
   averageCorr <- as.numeric(as.factor(averageCorr))
   x[lower.tri(x, diag = TRUE)] <- NA
