@@ -17,6 +17,7 @@ trainControl <- function(method = "boot",
                          sampling = NULL,
                          index = NULL,
                          indexOut = NULL,
+                         indexFinal = NULL,
                          timingSamps = 0,
                          predictionBounds = rep(FALSE, 2),
                          seeds = NA,
@@ -59,6 +60,7 @@ trainControl <- function(method = "boot",
        sampling = sampling,
        index = index,
        indexOut = indexOut,
+       indexFinal = indexFinal,
        timingSamps = timingSamps,
        predictionBounds = predictionBounds,
        seeds = seeds,
